@@ -78,7 +78,7 @@ def simGBM(s0=10, mu=0, sigma=0.2, r=0, T=1, dt=1 / 252, sims=1000, eps=None):
 
 
 def _import_csimOU():
-    dir = os.path.dirname(os.path.realpath(__file__)) + "/c/"
+    dir = os.path.dirname(os.path.realpath(__file__)) + "/../" #+ "/c/"
     lib = ctypes.cdll.LoadLibrary(dir + "simOU.so")
     fun = lib.csimOU
     fun.restype = None
@@ -558,3 +558,17 @@ if __name__ == "__main__":
     assert df.equals(act), "simGBM generated eps failed"
 
 
+
+
+def OU_lastcol(sims=100000, steps=250, T=25, sigma=.1, mu=1, theta=1, S0=1):     
+    # https://stackoverflow.com/questions/24973961/vectorizing-an-equation
+    dt = T/steps     
+    c = (1-theta*dt)
+    cv = c**_np.arange(steps)[::-1]
+
+    R = _np.random.normal(theta*mu*dt, sigma, (sims,steps))
+
+    SN = _np.dot(R, cv) + S0*c**steps
+    
+    df = _pd.DataFrame(SN)     
+    return df
\ No newline at end of file
